==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/SzablonBlokFtl.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class SzablonBlokFtl extends GenericDPSObject {
    /**
     * SZABLON_BLOK_FTL.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * SZABLON_BLOK_FTL.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long szablonWydrukuId;

    /**
     * SZABLON_BLOK_FTL.BLOK
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String blok;

    /**
     * SZABLON_BLOK_FTL.NUMER_PORZADKOWY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer numerPorzadkowy;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SZABLON_BLOK_FTL.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SZABLON_BLOK_FTL.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SZABLON_BLOK_FTL.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * SZABLON_BLOK_FTL.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return SZABLON_BLOK_FTL.BLOK
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getBlok() {
        return blok;
    }

    /**
     * SZABLON_BLOK_FTL.BLOK
     *
     * @param blok
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setBlok(String blok) {
        this.blok = blok == null ? null : blok.trim();
    }

    /**
     * @return SZABLON_BLOK_FTL.NUMER_PORZADKOWY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getNumerPorzadkowy() {
        return numerPorzadkowy;
    }

    /**
     * SZABLON_BLOK_FTL.NUMER_PORZADKOWY
     *
     * @param numerPorzadkowy
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNumerPorzadkowy(Integer numerPorzadkowy) {
        this.numerPorzadkowy = numerPorzadkowy;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SzablonBlokFtl other = (SzablonBlokFtl) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getBlok() == null ? other.getBlok() == null : this.getBlok().equals(other.getBlok()))
            && (this.getNumerPorzadkowy() == null ? other.getNumerPorzadkowy() == null : this.getNumerPorzadkowy().equals(other.getNumerPorzadkowy()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getBlok() == null) ? 0 : getBlok().hashCode());
        result = prime * result + ((getNumerPorzadkowy() == null) ? 0 : getNumerPorzadkowy().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", blok=").append(blok);
        sb.append(", numerPorzadkowy=").append(numerPorzadkowy);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/SzablonBlokFtl.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class SzablonBlokFtl extends GenericDPSObject {
    /**
     * SZABLON_BLOK_FTL.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * SZABLON_BLOK_FTL.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long szablonWydrukuId;

    /**
     * SZABLON_BLOK_FTL.BLOK
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String blok;

    /**
     * SZABLON_BLOK_FTL.NUMER_PORZADKOWY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer numerPorzadkowy;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SZABLON_BLOK_FTL.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SZABLON_BLOK_FTL.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SZABLON_BLOK_FTL.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * SZABLON_BLOK_FTL.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return SZABLON_BLOK_FTL.BLOK
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getBlok() {
        return blok;
    }

    /**
     * SZABLON_BLOK_FTL.BLOK
     *
     * @param blok
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setBlok(String blok) {
        this.blok = blok == null ? null : blok.trim();
    }

    /**
     * @return SZABLON_BLOK_FTL.NUMER_PORZADKOWY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getNumerPorzadkowy() {
        return numerPorzadkowy;
    }

    /**
     * SZABLON_BLOK_FTL.NUMER_PORZADKOWY
     *
     * @param numerPorzadkowy
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNumerPorzadkowy(Integer numerPorzadkowy) {
        this.numerPorzadkowy = numerPorzadkowy;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SzablonBlokFtl other = (SzablonBlokFtl) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getBlok() == null ? other.getBlok() == null : this.getBlok().equals(other.getBlok()))
            && (this.getNumerPorzadkowy() == null ? other.getNumerPorzadkowy() == null : this.getNumerPorzadkowy().equals(other.getNumerPorzadkowy()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getBlok() == null) ? 0 : getBlok().hashCode());
        result = prime * result + ((getNumerPorzadkowy() == null) ? 0 : getNumerPorzadkowy().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", blok=").append(blok);
        sb.append(", numerPorzadkowy=").append(numerPorzadkowy);
        sb.append("]");
        return sb.toString();
    }
}
